<?php

/**
 * Handles the admin functionalities and views.
 */
class WPECRS_Admin
{

	private $core_plugin_file = 'wp-express-checkout/wp-express-checkout.php';

	public function __construct()
	{
		add_action('admin_menu', array($this, 'add_admin_menus'));
	}

	public function add_admin_menus()
	{
		if (function_exists('add_options_page')) {
			add_options_page('WP Express Checkout Settings Reset', 'WPEC Reset', 'manage_options', 'wpec-reset-settings', array($this, 'reset_settings_page'));
		}
	}

	/**
	 * Detects whether the core WP Express Checkout plugin is active or not.
	 *
	 * @return boolean
	 */
	public function is_core_plugin_active()
	{
		return is_plugin_active($this->core_plugin_file);
	}

	/**
	 * Deactivates the WP Express Checkout core plugin.
	 */
	public function deactivate_core_plugin()
	{
		deactivate_plugins($this->core_plugin_file);
	}

	/**
	 * Renders the settings page in the admin.
	 *
	 * @return void
	 */
	public function reset_settings_page()
	{
?>
		<div class="wrap">
			<h2>WP Express Checkout Reset Settings & Data</h2>
			<?php
			if ($this->is_core_plugin_active()) {
				if (isset($_POST['wpecrs_deactivate_wpec']) && check_admin_referer('wpecrs-deactivate-wpec-nonce')) {
					// Deactivate the plugin
					$this->deactivate_core_plugin();
					// Redirect to the same page to reload the page with the deactivated plugin status.
					if(method_exists('WP_Express_Checkout\Utils', 'redirect_to_url')){
						WP_Express_Checkout\Utils::redirect_to_url(admin_url('options-general.php?page=wpec-reset-settings'));
					}
				} else {
			?>
					<div class="notice notice-error">
						<p>
							<span>
								<?php _e('You must deactivate the WP Express Checkout core plugin first to do the reset properly!', 'wp-express-checkout') ?>
							</span>
							<br>
							<br>
						<form action="" method="POST">
							<?php wp_nonce_field('wpecrs-deactivate-wpec-nonce'); ?>
							<button type="submit" name="wpecrs_deactivate_wpec" class="button-primary">
								<?php _e('Deactivate WP Express Checkout', 'wp-express-checkout') ?>
							</button>
						</form>
						</p>
					</div>
			<?php
					return;
				}
			} ?>

			<div class="wpecrs_info_box">
				<p>
					<?php _e('You can use the Factory Reset option to reset everything in one go, or selectively reset specific aspects of the plugin.', 'wp-express-checkout'); ?>
				</p>
			</div>

			<?php
			//Handle the form submissions
			if (isset($_POST['wpecrs_reset_all']) && check_admin_referer('wpecrs-reset-all-nonce')) {

				$results = WPECRS_Data_Handler::reset_all();

				foreach ($results as $result) {
					echo '<div class="notice notice-' . $result['status'] . '"><p>' . $result['message'] . '</p></div>';
				}
			}

			if (isset($_POST['wpecrs_reset_products']) && check_admin_referer('wpecrs-reset-products-nonce')) {

				$result = WPECRS_Data_Handler::reset_products_data();

				echo '<div class="notice notice-' . $result['status'] . '"><p>' . $result['message'] . '</p></div>';
			}

			if (isset($_POST['wpecrs_reset_taxonomies']) && check_admin_referer('wpecrs-reset-taxonomies-nonce')) {

				$result = WPECRS_Data_Handler::reset_taxonomies_data();

				echo '<div class="notice notice-' . $result['status'] . '"><p>' . $result['message'] . '</p></div>';
			}

			if (isset($_POST['wpecrs_reset_orders']) && check_admin_referer('wpecrs-reset-orders-nonce')) {

				$result = WPECRS_Data_Handler::reset_orders_data();

				echo '<div class="notice notice-' . $result['status'] . '"><p>' . $result['message'] . '</p></div>';
			}

			if (isset($_POST['wpecrs_reset_coupons']) && check_admin_referer('wpecrs-reset-coupons-nonce')) {

				$result = WPECRS_Data_Handler::reset_coupons_data();

				echo '<div class="notice notice-' . $result['status'] . '"><p>' . $result['message'] . '</p></div>';
			}

			if (isset($_POST['wpecrs_reset_admin_settings']) && check_admin_referer('wpecrs-reset-admin-settings-nonce')) { //Do form submission tasks

				$result = WPECRS_Data_Handler::reset_admin_settings();

				echo '<div class="notice notice-' . $result['status'] . '"><p>' . $result['message'] . '</p></div>';
			}

			//Display the forms
			$this->display_reset_all_form();
			$this->display_reset_products_form();
			$this->display_reset_taxonomies_form();
			$this->display_reset_orders_form();
			$this->display_reset_coupons_form();
			$this->display_reset_admin_settings_form();
			?>

			<style>
				.wpecrs_warning_box {
					background: #FFF6D5;
					border: 1px solid #D1B655;
					color: #3F2502;
					margin: 10px 0;
					padding: 5px 5px 5px 10px;
				}

				.wpecrs_info_box {
					background: #DDDDDD;
					border: 1px solid #CFCFCF;
					color: #363636;
					margin: 10px 0px 15px 0px;
					padding: 5px 5px 5px 10px;
				}
			</style>
		</div><!-- end of wrap -->
	<?php
	}

	public function display_reset_all_form()
	{
	?>
		<div id="poststuff">
			<div id="post-body">
				<form action="" method="POST" id="wpecrs_reset_all" onSubmit="if(!confirm('<?php _e('Are you sure?', 'wp-express-checkout') ?>')){return false;}">
					<?php wp_nonce_field('wpecrs-reset-all-nonce'); ?>
					<div class="postbox">
						<h3 class="hndle"><label for="title"><?php _e('Factory Reset', 'wp-express-checkout'); ?></label></h3>
						<div class="inside">
							<div class="wpecrs_warning_box">
								<p>
									<b>WARNING: </b>
									<span>
										<?php _e('This will erase everything of the WP Express Checkout plugin!', 'wp-express-checkout'); ?>
									</span>
								</p>
							</div>
							<button type="submit" class="button-primary"><?php _e('Reset', 'wp-express-checkout') ?></button>
							<input type="hidden" name="wpecrs_reset_all" />
						</div>
					</div>
				</form>
			</div>
		</div>
	<?php
	}

	public function display_reset_products_form()
	{
	?>
		<div id="poststuff">
			<div id="post-body">
				<form action="" method="POST" id="wpecrs_reset_products" onSubmit="if(!confirm('<?php _e('Are you sure?', 'wp-express-checkout') ?>')){return false;}">
					<?php wp_nonce_field('wpecrs-reset-products-nonce'); ?>
					<div class="postbox">
						<h3 class="hndle"><label for="title"><?php _e('Reset All Products\' Data', 'wp-express-checkout'); ?></label></h3>
						<div class="inside">
							<div class="wpecrs_warning_box">
								<p>
									<b>WARNING: </b>
									<span>
										<?php _e('This will delete all the products from the database that was created by the WP Express Checkout plugin!', 'wp-express-checkout'); ?>
									</span>
								</p>
							</div>
							<button type="submit" class="button-primary"><?php _e('Reset', 'wp-express-checkout') ?></button>
							<input type="hidden" name="wpecrs_reset_products" />
						</div>
					</div>
				</form>
			</div>
		</div>
	<?php
	}

	public function display_reset_taxonomies_form()
	{
	?>
		<div id="poststuff">
			<div id="post-body">
				<form action="" method="POST" id="wpecrs_reset_taxonomies" onSubmit="if(!confirm('<?php _e('Are you sure?', 'wp-express-checkout') ?>')){return false;}">
					<?php wp_nonce_field('wpecrs-reset-taxonomies-nonce'); ?>
					<div class="postbox">
						<h3 class="hndle"><label for="title"><?php _e('Reset All Taxonomies\' Data', 'wp-express-checkout'); ?></label></h3>
						<div class="inside">
							<div class="wpecrs_warning_box">
								<p>
									<b>WARNING: </b>
									<span>
										<?php _e('This will delete all the product taxonomies from the database that was created by the WP Express Checkout plugin!', 'wp-express-checkout'); ?>
									</span>
								</p>
							</div>
							<button type="submit" class="button-primary"><?php _e('Reset', 'wp-express-checkout') ?></button>
							<input type="hidden" name="wpecrs_reset_taxonomies" />
						</div>
					</div>
				</form>
			</div>
		</div>
	<?php
	}

	public function display_reset_orders_form()
	{
	?>
		<div id="poststuff">
			<div id="post-body">
				<form action="" method="POST" id="wpecrs_reset_orders" onSubmit="if(!confirm('<?php _e('Are you sure?', 'wp-express-checkout') ?>')){return false;}">
					<?php wp_nonce_field('wpecrs-reset-orders-nonce'); ?>
					<div class="postbox">
						<h3 class="hndle"><label for="title"><?php _e('Reset All Orders\' Data', 'wp-express-checkout'); ?></label></h3>
						<div class="inside">
							<div class="wpecrs_warning_box">
								<p>
									<b>WARNING: </b>
									<span>
										<?php _e('This will erase all orders data from the database that was created during checkout from the WP Express Checkout plugin!', 'wp-express-checkout'); ?>
									</span>
								</p>
							</div>
							<button type="submit" class="button-primary"><?php _e('Reset', 'wp-express-checkout') ?></button>
							<input type="hidden" name="wpecrs_reset_orders" />
						</div>
					</div>
				</form>
			</div>
		</div>
	<?php
	}

	public function display_reset_coupons_form()
	{
	?>
		<div id="poststuff">
			<div id="post-body">
				<form action="" method="POST" id="wpecrs_reset_coupons" onSubmit="if(!confirm('<?php _e('Are you sure?', 'wp-express-checkout') ?>')){return false;}">
					<?php wp_nonce_field('wpecrs-reset-coupons-nonce'); ?>
					<div class="postbox">
						<h3 class="hndle"><label for="title"><?php _e('Reset All Coupons\' Data', 'wp-express-checkout'); ?></label></h3>
						<div class="inside">
							<div class="wpecrs_warning_box">
								<p>
									<b>WARNING: </b>
									<span>
										<?php _e('This will erase all coupons\' data from the database that was created created by the WP Express Checkout plugin!', 'wp-express-checkout'); ?>
									</span>
								</p>
							</div>
							<button type="submit" class="button-primary"><?php _e('Reset', 'wp-express-checkout') ?></button>
							<input type="hidden" name="wpecrs_reset_coupons" />
						</div>
					</div>
				</form>
			</div>
		</div>
	<?php
	}

	public function display_reset_admin_settings_form()
	{
	?>
		<div id="poststuff">
			<div id="post-body">
				<form action="" method="POST" id="wpecrs_reset_admin_settings" onSubmit="if(!confirm('<?php _e('Are you sure?', 'wp-express-checkout') ?>')){return false;}">
					<?php wp_nonce_field('wpecrs-reset-admin-settings-nonce'); ?>
					<div class="postbox">
						<h3 class="hndle"><label for="title"><?php _e('Reset Admin Settings', 'wp-express-checkout'); ?></label></h3>
						<div class="inside">
							<div class="wpecrs_warning_box">
								<p>
									<b>WARNING: </b>
									<span>
										<?php _e('This will reset all the admin settings data of the WP Express Checkout plugin!', 'wp-express-checkout'); ?>
									</span>
								</p>
							</div>
							<button type="submit" class="button-primary"><?php _e('Reset', 'wp-express-checkout') ?></button>
							<input type="hidden" name="wpecrs_reset_admin_settings" />
						</div>
					</div>
				</form>
			</div>
		</div>
<?php
	}
}
