<?php

/**
 * Class used to communicate to the plugin's data in the database.
 */
class WPECRS_Data_Handler
{
	/**
	 * Retrieves the custom post type count.
	 *
	 * @param string Name of the cpt
	 * @return int Total count
	 */
	public static function get_cpt_count($cpt)
	{
		global $wpdb;

		$count = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->posts WHERE post_type='$cpt';");

		return $count;
	}

	/**
	 * Retrieves the taxonomies count.
	 *
	 * @param string Name of the taxonomy
	 * @return int Total count
	 */
	public static function get_taxonomy_count($taxonomy)
	{
		global $wpdb;

		$count = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->term_taxonomy WHERE taxonomy='$taxonomy';");

		return $count;
	}

	/**
	 * Delete the Products and its associated post meta created by the WP Express Checkout Plugin.
	 *
	 * CPT: ppec-products
	 *
	 * @return array Query result
	 */
	public static function reset_products_data()
	{
		global $wpdb;

		if (self::get_cpt_count('ppec-products') > 0) {
			$is_success = $wpdb->query(
				"DELETE a,b 
						FROM $wpdb->posts a 
						LEFT JOIN $wpdb->postmeta b ON a.ID = b.post_id 
						WHERE a.post_type='ppec-products';"
			);

			if ($is_success) {
				return [
					'message' => __('WP Express Checkout products were deleted successfully.', 'wp-express-checkout'),
					'status' => 'success',
					'is_success' => true
				];
			} else {
				return [
					'message' => __('Deletion of WP Express Checkout products failed.', 'wp-express-checkout'),
					'status' => 'error',
					'is_success' => false
				];
			}
		}

		return [
			'message' => __('No products found!', 'wp-express-checkout'),
			'status' => 'warning',
			'is_success' => true
		];
	}

	/**
	 * Delete the Taxonomies and its associated post meta created by the WP Express Checkout Plugin.
	 *
	 * CPT: wpec_categories
	 *
	 * @return array Query result
	 */
	public static function reset_taxonomies_data()
	{
		global $wpdb;

		if (self::get_taxonomy_count('wpec_categories') > 0) {
			$is_success = $wpdb->query(
				"DELETE a,b,c
				FROM      $wpdb->term_taxonomy      a
				LEFT JOIN $wpdb->term_relationships b ON a.term_taxonomy_id = b.term_taxonomy_id
				LEFT JOIN $wpdb->terms              c ON a.term_id = c.term_id
				WHERE a.taxonomy = 'wpec_categories'"
			);

			if ($is_success) {
				return [
					'message' => __('WP Express Checkout product taxonomies were deleted successfully.', 'wp-express-checkout'),
					'status' => 'success',
					'is_success' => true
				];
			} else {
				return [
					'message' => __('Deletion of WP Express Checkout product taxonomies failed.', 'wp-express-checkout'),
					'status' => 'error',
					'is_success' => false
				];
			}
		}

		return [
			'message' => __('No taxonomies found!', 'wp-express-checkout'),
			'status' => 'warning',
			'is_success' => true
		];
	}

	/**
	 * Delete the Orders and its associated post meta created by the WP Express Checkout Plugin.
	 *
	 * CPT: ppdgorder
	 *
	 * @return array Query result
	 */
	public static function reset_orders_data()
	{
		global $wpdb;

		if (self::get_cpt_count('ppdgorder') > 0) {
			$is_success = $wpdb->query(
				"DELETE a,b 
								FROM $wpdb->posts a 
								LEFT JOIN $wpdb->postmeta b ON a.ID = b.post_id 
								WHERE a.post_type='ppdgorder';"
			);

			if ($is_success) {
				return [
					'message' => __('WP Express Checkout orders were deleted successfully.', 'wp-express-checkout'),
					'status' => 'success',
					'is_success' => true
				];
			} else {
				return [
					'message' => __('Deletion of WP Express Checkout orders failed.', 'wp-express-checkout'),
					'status' => 'error',
					'is_success' => false
				];
			}
		}

		return [
			'message' => __('No orders found!', 'wp-express-checkout'),
			'status' => 'warning',
			'is_success' => true
		];
	}

	/**
	 * Delete the Coupons and its associated post meta created by the WP Express Checkout Plugin.
	 *
	 * CPT: wpec_coupons
	 *
	 * @return array Query result
	 */
	public static function reset_coupons_data()
	{
		global $wpdb;

		if (self::get_cpt_count('wpec_coupons') > 0) {
			$is_success = $wpdb->query(
				"DELETE a,b 
					FROM $wpdb->posts a 
					LEFT JOIN $wpdb->postmeta b ON a.ID = b.post_id 
					WHERE a.post_type='wpec_coupons';"
			);

			if ($is_success) {
				return [
					'message' => __('WP Express Checkout coupons were deleted successfully.', 'wp-express-checkout'),
					'status' => 'success',
					'is_success' => true
				];
			} else {
				return [
					'message' => __('Deletion of WP Express Checkout coupons failed.', 'wp-express-checkout'),
					'status' => 'error',
					'is_success' => false
				];
			}
		}

		return [
			'message' => __('No coupons found!', 'wp-express-checkout'),
			'status' => 'warning',
			'is_success' => true
		];
	}


	/**
	 * Delete all WP Express Checkout admin settings.
	 *
	 * Settings name: ppdg-settings
	 * 
	 * @return array Query result
	 */
	public static function reset_admin_settings()
	{
		$options = get_option("ppdg-settings", false);

		if ($options === false) {
			return [
				'message' => __('No settings found!', 'wp-express-checkout'),
				'status' => 'warning',
				'is_success' => true
			];
		}

		$is_success = delete_option('ppdg-settings');

		if ($is_success) {
			return [
				'message' => __('WP Express Checkout options were deleted successfully.', 'wp-express-checkout'),
				'status' => 'success',
				'is_success' => true
			];
		}

		return [
			'message' => __('Deletion of WP Express Checkout options failed.', 'wp-express-checkout'),
			'status' => 'error',
			'is_success' => false
		];
	}

	/**
	 * Delete everything related to WP Express Checkout plugin.
	 *
	 * @return array
	 */
	public static function reset_all()
	{
		$results = [];
		$results[] = self::reset_products_data();
		$results[] = self::reset_taxonomies_data();
		$results[] = self::reset_orders_data();
		$results[] = self::reset_coupons_data();
		$results[] = self::reset_admin_settings();

		return $results;
	}
}
